Periodic
--------

.. currentmodule:: prismstudio

.. autosummary::
    :toctree: api/

    _PrismComponent.period_max
    _PrismComponent.period_min
    _PrismComponent.period_mean
    _PrismComponent.period_std
    _PrismComponent.period_var
    _PrismComponent.period_median
    _PrismComponent.period_sum
    _PrismComponent.period_z_score
    _PrismComponent.period_count

